PermutationKey

Struct PermutationKey 

pub struct PermutationKey<const N: usize>(/* private fields */);

Implementations

Source

impl<const N: usize> PermutationKey<N>

pub unsafe fn new_unchecked(key: [u8; N]) -> Self

Safety

This function is unsafe because it does not check that the key is a valid permutation.

pub fn from_seed(seed: [u8; 32]) -> Result<Self, RandomError>
where [u8; N]: IsPermutable,

Creates a new permutation key from a seed. TODO: Perhaps seed should be protected?

pub fn invert(self) -> Self
where [u8; N]: IsPermutable,

Consumes the key and returns its inverse.

pub fn complement(&self, target: &Self) -> Self
where [u8; N]: IsPermutable + Zeroed,

Returns the complement of the key with respect to the target key. That is: C(T) = Self

Example
use vitaminc::permutation::{Permute, PermutationKey};
use vitaminc::random::{Generatable, SafeRand, SeedableRng};
let mut rng = SafeRand::from_entropy().expect("Failed to seed RNG");
let key = PermutationKey::random(&mut rng).expect("Random error");
let target = PermutationKey::random(&mut rng).expect("Random error");
let complement = key.complement(&target);
let input: [u8; 16] = Generatable::random(&mut rng).expect("Random error");
assert_eq!(
    complement.permute(target).permute(input),
    key.permute(input)
);