pub struct PermutationKey<const N: usize>(/* private fields */);Implementations
Sourceimpl<const N: usize> PermutationKey<N>
impl<const N: usize> PermutationKey<N>
Sourcepub unsafe fn new_unchecked(key: [u8; N]) -> Self
pub unsafe fn new_unchecked(key: [u8; N]) -> Self
Safety
This function is unsafe because it does not check that the key is a valid permutation.
Sourcepub fn from_seed(seed: [u8; 32]) -> Result<Self, RandomError>
pub fn from_seed(seed: [u8; 32]) -> Result<Self, RandomError>
Creates a new permutation key from a seed. TODO: Perhaps seed should be protected?
Sourcepub fn complement(&self, target: &Self) -> Self
pub fn complement(&self, target: &Self) -> Self
Returns the complement of the key with respect to the target key.
That is: C(T) = Self
Example
use vitaminc::permutation::{Permute, PermutationKey};
use vitaminc::random::{Generatable, SafeRand, SeedableRng};
let mut rng = SafeRand::from_entropy().expect("Failed to seed RNG");
let key = PermutationKey::random(&mut rng).expect("Random error");
let target = PermutationKey::random(&mut rng).expect("Random error");
let complement = key.complement(&target);
let input: [u8; 16] = Generatable::random(&mut rng).expect("Random error");
assert_eq!(
complement.permute(target).permute(input),
key.permute(input)
);Trait Implementations
Sourceimpl BitwisePermute<8, NonZero<u8>> for PermutationKey<8>
impl BitwisePermute<8, NonZero<u8>> for PermutationKey<8>
fn bitwise_permute(&self, input: NonZeroU8) -> NonZeroU8
Sourceimpl BitwisePermute<8, u8> for PermutationKey<8>
impl BitwisePermute<8, u8> for PermutationKey<8>
fn bitwise_permute(&self, input: u8) -> u8
Sourceimpl BitwisePermute<16, NonZero<u16>> for PermutationKey<16>
impl BitwisePermute<16, NonZero<u16>> for PermutationKey<16>
fn bitwise_permute(&self, input: NonZeroU16) -> NonZeroU16
Sourceimpl BitwisePermute<16, u16> for PermutationKey<16>
impl BitwisePermute<16, u16> for PermutationKey<16>
fn bitwise_permute(&self, input: u16) -> u16
Sourceimpl BitwisePermute<32, NonZero<u32>> for PermutationKey<32>
impl BitwisePermute<32, NonZero<u32>> for PermutationKey<32>
fn bitwise_permute(&self, input: NonZeroU32) -> NonZeroU32
Sourceimpl BitwisePermute<32, u32> for PermutationKey<32>
impl BitwisePermute<32, u32> for PermutationKey<32>
fn bitwise_permute(&self, input: u32) -> u32
Sourceimpl BitwisePermute<64, NonZero<u64>> for PermutationKey<64>
impl BitwisePermute<64, NonZero<u64>> for PermutationKey<64>
fn bitwise_permute(&self, input: NonZeroU64) -> NonZeroU64
Sourceimpl BitwisePermute<64, u64> for PermutationKey<64>
impl BitwisePermute<64, u64> for PermutationKey<64>
fn bitwise_permute(&self, input: u64) -> u64
Sourceimpl BitwisePermute<128, NonZero<u128>> for PermutationKey<128>
impl BitwisePermute<128, NonZero<u128>> for PermutationKey<128>
fn bitwise_permute(&self, input: NonZeroU128) -> NonZeroU128
Sourceimpl BitwisePermute<128, u128> for PermutationKey<128>
impl BitwisePermute<128, u128> for PermutationKey<128>
fn bitwise_permute(&self, input: u128) -> u128
Sourceimpl<const N: usize> Clone for PermutationKey<N>
impl<const N: usize> Clone for PermutationKey<N>
Sourcefn clone(&self) -> PermutationKey<N>
fn clone(&self) -> PermutationKey<N>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl<const N: usize> Copy for PermutationKey<N>
Sourceimpl<const N: usize> Debug for PermutationKey<N>
impl<const N: usize> Debug for PermutationKey<N>
Sourceimpl<'de, const N: usize> Deserialize<'de> for PermutationKey<N>
impl<'de, const N: usize> Deserialize<'de> for PermutationKey<N>
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<const N: usize> Generatable for PermutationKey<N>
impl<const N: usize> Generatable for PermutationKey<N>
Sourceimpl<const N: usize> Permute<PermutationKey<N>> for PermutationKey<N>
impl<const N: usize> Permute<PermutationKey<N>> for PermutationKey<N>
Sourceimpl<const N: usize, T> Permute<[T; N]> for PermutationKey<N>
Implement permutation for Protected type containing a permutable array.
impl<const N: usize, T> Permute<[T; N]> for PermutationKey<N>
Implement permutation for Protected type containing a permutable array.
Sourceimpl<const N: usize> Serialize for PermutationKey<N>
impl<const N: usize> Serialize for PermutationKey<N>